@@ -179,15 +179,25 @@ class HttpOrigin(
 
     Example::
 
-        my_bucket = s3.Bucket(self, "myBucket")
-        cloudfront.Distribution(self, "myDist",
+        # Validating signed URLs or signed cookies with Trusted Key Groups
+        
+        # public key in PEM format
+        # public_key: str
+        
+        pub_key = cloudfront.PublicKey(self, "MyPubKey",
+            encoded_key=public_key
+        )
+        
+        key_group = cloudfront.KeyGroup(self, "MyKeyGroup",
+            items=[pub_key
+            ]
+        )
+        
+        cloudfront.Distribution(self, "Dist",
             default_behavior=cloudfront.BehaviorOptions(
-                origin=origins.OriginGroup(
-                    primary_origin=origins.S3Origin(my_bucket),
-                    fallback_origin=origins.HttpOrigin("www.example.com"),
-                    # optional, defaults to: 500, 502, 503 and 504
-                    fallback_status_codes=[404]
-                )
+                origin=origins.HttpOrigin("www.example.com"),
+                trusted_key_groups=[key_group
+                ]
             )
         )
     '''
