@@ -80,7 +80,7 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnResource as _CfnResource_9df397a6,
     IInspectable as _IInspectable_c2943556,
@@ -112,8 +112,6 @@ class CfnNotificationRule(
         # The values are placeholders you should change.
         from aws_cdk import aws_codestarnotifications as codestarnotifications
         
-        # tags: Any
-        
         cfn_notification_rule = codestarnotifications.CfnNotificationRule(self, "MyCfnNotificationRule",
             detail_type="detailType",
             event_type_ids=["eventTypeIds"],
@@ -128,25 +126,27 @@ class CfnNotificationRule(
             created_by="createdBy",
             event_type_id="eventTypeId",
             status="status",
-            tags=tags,
+            tags={
+                "tags_key": "tags"
+            },
             target_address="targetAddress"
         )
     '''
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         detail_type: builtins.str,
         event_type_ids: typing.Sequence[builtins.str],
         name: builtins.str,
         resource: builtins.str,
-        targets: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[typing.Union["CfnNotificationRule.TargetProperty", typing.Dict[str, typing.Any]], _IResolvable_da3f097b]]],
+        targets: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union["CfnNotificationRule.TargetProperty", typing.Dict[builtins.str, typing.Any]]]]],
         created_by: typing.Optional[builtins.str] = None,
         event_type_id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
-        tags: typing.Any = None,
+        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         target_address: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Create a new ``AWS::CodeStarNotifications::NotificationRule``.
@@ -154,10 +154,10 @@ class CfnNotificationRule(
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
         :param detail_type: The level of detail to include in the notifications for this resource. ``BASIC`` will include only the contents of the event as it would appear in Amazon CloudWatch. ``FULL`` will include any supplemental information provided by AWS CodeStar Notifications and/or the service for the resource for which the notification is created.
-        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
         :param name: The name for the notification rule. Notification rule names must be unique in your AWS account .
         :param resource: The Amazon Resource Name (ARN) of the resource to associate with the notification rule. Supported resources include pipelines in AWS CodePipeline , repositories in AWS CodeCommit , and build projects in AWS CodeBuild .
-        :param targets: A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        :param targets: A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
         :param created_by: ``AWS::CodeStarNotifications::NotificationRule.CreatedBy``.
         :param event_type_id: ``AWS::CodeStarNotifications::NotificationRule.EventTypeId``.
         :param status: The status of the notification rule. The default value is ``ENABLED`` . If the status is set to ``DISABLED`` , notifications aren't sent for the notification rule.
@@ -165,7 +165,7 @@ class CfnNotificationRule(
         :param target_address: ``AWS::CodeStarNotifications::NotificationRule.TargetAddress``.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnNotificationRule.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__724996b7b605c1ccec7fc232a8e933db042d262c4932936112f67cf6c1086ace)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnNotificationRuleProps(
@@ -190,7 +190,7 @@ class CfnNotificationRule(
         :param inspector: - tree inspector to collect and process attributes.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnNotificationRule.inspect)
+            type_hints = typing.get_type_hints(_typecheckingstub__87ef25f46cfb8cebf7f1dcf20988342af27ada2610c31d3973ea93bae9079a0c)
             check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -203,7 +203,7 @@ class CfnNotificationRule(
         :param props: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnNotificationRule._render_properties)
+            type_hints = typing.get_type_hints(_typecheckingstub__40d4fee78d1cb9b3932feffc8bdedc027a5eb171eb25256c49259b1081959e4d)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
@@ -251,7 +251,7 @@ class CfnNotificationRule(
     @detail_type.setter
     def detail_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "detail_type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e77575e9e7fed1aaa856782984f55190cacebb0127b3a420e5abd83c05124eb6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "detailType", value)
 
@@ -260,7 +260,7 @@ class CfnNotificationRule(
     def event_type_ids(self) -> typing.List[builtins.str]:
         '''A list of event types associated with this notification rule.
 
-        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-eventtypeids
         '''
@@ -269,7 +269,7 @@ class CfnNotificationRule(
     @event_type_ids.setter
     def event_type_ids(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "event_type_ids").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__fb90cf2b1d4d9f08c073745d794c6b1baab1fbeeb5c0bbda2d12a48b0d9f5108)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeIds", value)
 
@@ -287,7 +287,7 @@ class CfnNotificationRule(
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "name").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5204aa375f9e4e9997555d623037738864aa5e6cea213dafa3cc2dbd08fe4b5f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -305,7 +305,7 @@ class CfnNotificationRule(
     @resource.setter
     def resource(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__a9e7eb7809f54a6ab1cc7633e54f753ffc88aee5242769abb918737ba1ece93e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "resource", value)
 
@@ -313,20 +313,20 @@ class CfnNotificationRule(
     @jsii.member(jsii_name="targets")
     def targets(
         self,
-    ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_da3f097b]]]:
-        '''A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+    ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnNotificationRule.TargetProperty"]]]:
+        '''A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         '''
-        return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_da3f097b]]], jsii.get(self, "targets"))
+        return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnNotificationRule.TargetProperty"]]], jsii.get(self, "targets"))
 
     @targets.setter
     def targets(
         self,
-        value: typing.Union[_IResolvable_da3f097b, typing.List[typing.Union["CfnNotificationRule.TargetProperty", _IResolvable_da3f097b]]],
+        value: typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, "CfnNotificationRule.TargetProperty"]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "targets").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__4259d2e21a6aa16f5b382a6da87f39d19bce9c3ff108949185b9a52a0cdc3fb1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targets", value)
 
@@ -342,7 +342,7 @@ class CfnNotificationRule(
     @created_by.setter
     def created_by(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "created_by").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d3a38c963a2f57c2eef37336737a4291ab12ddbea2f275489ad41a0f3b1626c2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "createdBy", value)
 
@@ -358,7 +358,7 @@ class CfnNotificationRule(
     @event_type_id.setter
     def event_type_id(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "event_type_id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3f4c0a2f101ac5756c08ca6fb073dca683dc73b0a107311500211b14b0fa45bd)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventTypeId", value)
 
@@ -376,7 +376,7 @@ class CfnNotificationRule(
     @status.setter
     def status(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "status").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__912dbe323db8cf96405e266076a8cdf4072b4a2dd758c0d981017c758190eab3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "status", value)
 
@@ -392,7 +392,7 @@ class CfnNotificationRule(
     @target_address.setter
     def target_address(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(CfnNotificationRule, "target_address").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0b60a2bf9b823ac3550ee164c0b5272642cbc4e5c916ec347fa569051a338b1b)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "targetAddress", value)
 
@@ -428,10 +428,10 @@ class CfnNotificationRule(
                 )
             '''
             if __debug__:
-                type_hints = typing.get_type_hints(CfnNotificationRule.TargetProperty.__init__)
+                type_hints = typing.get_type_hints(_typecheckingstub__c5808f80235ebed2f288b2e5e65437084fde23b48cb2a5daa84d6bf156a1aa57)
                 check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
                 check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
-            self._values: typing.Dict[str, typing.Any] = {
+            self._values: typing.Dict[builtins.str, typing.Any] = {
                 "target_address": target_address,
                 "target_type": target_type,
             }
@@ -495,20 +495,20 @@ class CfnNotificationRuleProps:
         event_type_ids: typing.Sequence[builtins.str],
         name: builtins.str,
         resource: builtins.str,
-        targets: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[str, typing.Any]], _IResolvable_da3f097b]]],
+        targets: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]]]]],
         created_by: typing.Optional[builtins.str] = None,
         event_type_id: typing.Optional[builtins.str] = None,
         status: typing.Optional[builtins.str] = None,
-        tags: typing.Any = None,
+        tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         target_address: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Properties for defining a ``CfnNotificationRule``.
 
         :param detail_type: The level of detail to include in the notifications for this resource. ``BASIC`` will include only the contents of the event as it would appear in Amazon CloudWatch. ``FULL`` will include any supplemental information provided by AWS CodeStar Notifications and/or the service for the resource for which the notification is created.
-        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        :param event_type_ids: A list of event types associated with this notification rule. For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
         :param name: The name for the notification rule. Notification rule names must be unique in your AWS account .
         :param resource: The Amazon Resource Name (ARN) of the resource to associate with the notification rule. Supported resources include pipelines in AWS CodePipeline , repositories in AWS CodeCommit , and build projects in AWS CodeBuild .
-        :param targets: A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+        :param targets: A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
         :param created_by: ``AWS::CodeStarNotifications::NotificationRule.CreatedBy``.
         :param event_type_id: ``AWS::CodeStarNotifications::NotificationRule.EventTypeId``.
         :param status: The status of the notification rule. The default value is ``ENABLED`` . If the status is set to ``DISABLED`` , notifications aren't sent for the notification rule.
@@ -524,8 +524,6 @@ class CfnNotificationRuleProps:
             # The values are placeholders you should change.
             from aws_cdk import aws_codestarnotifications as codestarnotifications
             
-            # tags: Any
-            
             cfn_notification_rule_props = codestarnotifications.CfnNotificationRuleProps(
                 detail_type="detailType",
                 event_type_ids=["eventTypeIds"],
@@ -540,12 +538,14 @@ class CfnNotificationRuleProps:
                 created_by="createdBy",
                 event_type_id="eventTypeId",
                 status="status",
-                tags=tags,
+                tags={
+                    "tags_key": "tags"
+                },
                 target_address="targetAddress"
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnNotificationRuleProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__952abbe5911505f5e5382fd91146586f2692114d447a4f16d4f5749cae4799fe)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument event_type_ids", value=event_type_ids, expected_type=type_hints["event_type_ids"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
@@ -556,7 +556,7 @@ class CfnNotificationRuleProps:
             check_type(argname="argument status", value=status, expected_type=type_hints["status"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
             check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "detail_type": detail_type,
             "event_type_ids": event_type_ids,
             "name": name,
@@ -590,7 +590,7 @@ class CfnNotificationRuleProps:
     def event_type_ids(self) -> typing.List[builtins.str]:
         '''A list of event types associated with this notification rule.
 
-        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/codestar-notifications/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
+        For a complete list of event types and IDs, see `Notification concepts <https://docs.aws.amazon.com/dtconsole/latest/userguide/concepts.html#concepts-api>`_ in the *Developer Tools Console User Guide* .
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-eventtypeids
         '''
@@ -625,14 +625,14 @@ class CfnNotificationRuleProps:
     @builtins.property
     def targets(
         self,
-    ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[CfnNotificationRule.TargetProperty, _IResolvable_da3f097b]]]:
-        '''A list of Amazon Resource Names (ARNs) of AWS Chatbot topics and AWS Chatbot clients to associate with the notification rule.
+    ) -> typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnNotificationRule.TargetProperty]]]:
+        '''A list of Amazon Resource Names (ARNs) of Amazon Simple Notification Service topics and AWS Chatbot clients to associate with the notification rule.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-targets
         '''
         result = self._values.get("targets")
         assert result is not None, "Required property 'targets' is missing"
-        return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[CfnNotificationRule.TargetProperty, _IResolvable_da3f097b]]], result)
+        return typing.cast(typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnNotificationRule.TargetProperty]]], result)
 
     @builtins.property
     def created_by(self) -> typing.Optional[builtins.str]:
@@ -664,7 +664,7 @@ class CfnNotificationRuleProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def tags(self) -> typing.Any:
+    def tags(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         '''A list of tags to apply to this notification rule.
 
         Key names cannot start with " ``aws`` ".
@@ -672,7 +672,7 @@ class CfnNotificationRuleProps:
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarnotifications-notificationrule.html#cfn-codestarnotifications-notificationrule-tags
         '''
         result = self._values.get("tags")
-        return typing.cast(typing.Any, result)
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
     @builtins.property
     def target_address(self) -> typing.Optional[builtins.str]:
@@ -754,7 +754,7 @@ class _INotificationRuleProxy(
         :return: boolean - return true if it had any effect
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(INotificationRule.add_target)
+            type_hints = typing.get_type_hints(_typecheckingstub__83568cba2bd196cd0611084c807a07f3158a16140c8d6c4d35238d6419431a3e)
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
@@ -771,7 +771,7 @@ class INotificationRuleSource(typing_extensions.Protocol):
     @jsii.member(jsii_name="bindAsNotificationRuleSource")
     def bind_as_notification_rule_source(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleSourceConfig":
         '''Returns a source configuration for notification rule.
 
@@ -788,14 +788,14 @@ class _INotificationRuleSourceProxy:
     @jsii.member(jsii_name="bindAsNotificationRuleSource")
     def bind_as_notification_rule_source(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleSourceConfig":
         '''Returns a source configuration for notification rule.
 
         :param scope: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(INotificationRuleSource.bind_as_notification_rule_source)
+            type_hints = typing.get_type_hints(_typecheckingstub__5450ef736fad66a5746a2acf129158273757bccca5695cd9088cbd31c1190d4a)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleSourceConfig", jsii.invoke(self, "bindAsNotificationRuleSource", [scope]))
 
@@ -812,7 +812,7 @@ class INotificationRuleTarget(typing_extensions.Protocol):
     @jsii.member(jsii_name="bindAsNotificationRuleTarget")
     def bind_as_notification_rule_target(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleTargetConfig":
         '''Returns a target configuration for notification rule.
 
@@ -829,14 +829,14 @@ class _INotificationRuleTargetProxy:
     @jsii.member(jsii_name="bindAsNotificationRuleTarget")
     def bind_as_notification_rule_target(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
     ) -> "NotificationRuleTargetConfig":
         '''Returns a target configuration for notification rule.
 
         :param scope: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(INotificationRuleTarget.bind_as_notification_rule_target)
+            type_hints = typing.get_type_hints(_typecheckingstub__1aabe87bcc3bcfcb31e776adf52a667c84dfa7282f1c25dd08dd858cf88b5792)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         return typing.cast("NotificationRuleTargetConfig", jsii.invoke(self, "bindAsNotificationRuleTarget", [scope]))
 
@@ -884,7 +884,7 @@ class NotificationRule(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         events: typing.Sequence[builtins.str],
@@ -905,7 +905,7 @@ class NotificationRule(
         :param notification_rule_name: The name for the notification rule. Notification rule names must be unique in your AWS account. Default: - generated from the ``id``
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRule.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2ee042127cf39a85f944067772f0419c8ac6769379b69d847458271eeb8ab318)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = NotificationRuleProps(
@@ -923,7 +923,7 @@ class NotificationRule(
     @builtins.classmethod
     def from_notification_rule_arn(
         cls,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         notification_rule_arn: builtins.str,
     ) -> INotificationRule:
@@ -934,7 +934,7 @@ class NotificationRule(
         :param notification_rule_arn: Notification rule ARN (i.e. arn:aws:codestar-notifications:::notificationrule/01234abcde).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRule.from_notification_rule_arn)
+            type_hints = typing.get_type_hints(_typecheckingstub__c632c338e62acde6cbe6e9a621df456c5b97c1a83557f6e8004c96305cca6d53)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument notification_rule_arn", value=notification_rule_arn, expected_type=type_hints["notification_rule_arn"])
@@ -947,7 +947,7 @@ class NotificationRule(
         :param target: The SNS topic or AWS Chatbot Slack target.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRule.add_target)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ae4822f460efa58f235b9774da89d7f779da55fe51601a3cdfdf7b24e56913c)
             check_type(argname="argument target", value=target, expected_type=type_hints["target"])
         return typing.cast(builtins.bool, jsii.invoke(self, "addTarget", [target]))
 
@@ -999,11 +999,11 @@ class NotificationRuleOptions:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRuleOptions.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__eefabcfdf7bed8d3d87d052ee762b71c3b6147378fc2dcef592f76197869ec52)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
             check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if detail_type is not None:
             self._values["detail_type"] = detail_type
         if enabled is not None:
@@ -1118,14 +1118,14 @@ class NotificationRuleProps(NotificationRuleOptions):
             rule.add_target(slack)
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRuleProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__07e191339712f728b76ba8a634b1678dff009608132b685c7342315eab988d78)
             check_type(argname="argument detail_type", value=detail_type, expected_type=type_hints["detail_type"])
             check_type(argname="argument enabled", value=enabled, expected_type=type_hints["enabled"])
             check_type(argname="argument notification_rule_name", value=notification_rule_name, expected_type=type_hints["notification_rule_name"])
             check_type(argname="argument events", value=events, expected_type=type_hints["events"])
             check_type(argname="argument source", value=source, expected_type=type_hints["source"])
             check_type(argname="argument targets", value=targets, expected_type=type_hints["targets"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "events": events,
             "source": source,
         }
@@ -1241,9 +1241,9 @@ class NotificationRuleSourceConfig:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRuleSourceConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4d360e17c334b6a0f70e67ffff0c1887ea63e43f8b4efcce27df4db191f21ce0)
             check_type(argname="argument source_arn", value=source_arn, expected_type=type_hints["source_arn"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "source_arn": source_arn,
         }
 
@@ -1297,10 +1297,10 @@ class NotificationRuleTargetConfig:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(NotificationRuleTargetConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__a6f32c99ca69e59363f10dc680579548d678dad8805ff6c48b7a60d0aa5f940c)
             check_type(argname="argument target_address", value=target_address, expected_type=type_hints["target_address"])
             check_type(argname="argument target_type", value=target_type, expected_type=type_hints["target_type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "target_address": target_address,
             "target_type": target_type,
         }
@@ -1349,3 +1349,193 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__724996b7b605c1ccec7fc232a8e933db042d262c4932936112f67cf6c1086ace(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    detail_type: builtins.str,
+    event_type_ids: typing.Sequence[builtins.str],
+    name: builtins.str,
+    resource: builtins.str,
+    targets: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]]]]],
+    created_by: typing.Optional[builtins.str] = None,
+    event_type_id: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    target_address: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__87ef25f46cfb8cebf7f1dcf20988342af27ada2610c31d3973ea93bae9079a0c(
+    inspector: _TreeInspector_488e0dd5,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__40d4fee78d1cb9b3932feffc8bdedc027a5eb171eb25256c49259b1081959e4d(
+    props: typing.Mapping[builtins.str, typing.Any],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e77575e9e7fed1aaa856782984f55190cacebb0127b3a420e5abd83c05124eb6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fb90cf2b1d4d9f08c073745d794c6b1baab1fbeeb5c0bbda2d12a48b0d9f5108(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5204aa375f9e4e9997555d623037738864aa5e6cea213dafa3cc2dbd08fe4b5f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a9e7eb7809f54a6ab1cc7633e54f753ffc88aee5242769abb918737ba1ece93e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4259d2e21a6aa16f5b382a6da87f39d19bce9c3ff108949185b9a52a0cdc3fb1(
+    value: typing.Union[_IResolvable_da3f097b, typing.List[typing.Union[_IResolvable_da3f097b, CfnNotificationRule.TargetProperty]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d3a38c963a2f57c2eef37336737a4291ab12ddbea2f275489ad41a0f3b1626c2(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3f4c0a2f101ac5756c08ca6fb073dca683dc73b0a107311500211b14b0fa45bd(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__912dbe323db8cf96405e266076a8cdf4072b4a2dd758c0d981017c758190eab3(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0b60a2bf9b823ac3550ee164c0b5272642cbc4e5c916ec347fa569051a338b1b(
+    value: typing.Optional[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c5808f80235ebed2f288b2e5e65437084fde23b48cb2a5daa84d6bf156a1aa57(
+    *,
+    target_address: builtins.str,
+    target_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__952abbe5911505f5e5382fd91146586f2692114d447a4f16d4f5749cae4799fe(
+    *,
+    detail_type: builtins.str,
+    event_type_ids: typing.Sequence[builtins.str],
+    name: builtins.str,
+    resource: builtins.str,
+    targets: typing.Union[_IResolvable_da3f097b, typing.Sequence[typing.Union[_IResolvable_da3f097b, typing.Union[CfnNotificationRule.TargetProperty, typing.Dict[builtins.str, typing.Any]]]]],
+    created_by: typing.Optional[builtins.str] = None,
+    event_type_id: typing.Optional[builtins.str] = None,
+    status: typing.Optional[builtins.str] = None,
+    tags: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    target_address: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__83568cba2bd196cd0611084c807a07f3158a16140c8d6c4d35238d6419431a3e(
+    target: INotificationRuleTarget,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5450ef736fad66a5746a2acf129158273757bccca5695cd9088cbd31c1190d4a(
+    scope: _constructs_77d1e7e8.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1aabe87bcc3bcfcb31e776adf52a667c84dfa7282f1c25dd08dd858cf88b5792(
+    scope: _constructs_77d1e7e8.Construct,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2ee042127cf39a85f944067772f0419c8ac6769379b69d847458271eeb8ab318(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    events: typing.Sequence[builtins.str],
+    source: INotificationRuleSource,
+    targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c632c338e62acde6cbe6e9a621df456c5b97c1a83557f6e8004c96305cca6d53(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    notification_rule_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7ae4822f460efa58f235b9774da89d7f779da55fe51601a3cdfdf7b24e56913c(
+    target: INotificationRuleTarget,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__eefabcfdf7bed8d3d87d052ee762b71c3b6147378fc2dcef592f76197869ec52(
+    *,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__07e191339712f728b76ba8a634b1678dff009608132b685c7342315eab988d78(
+    *,
+    detail_type: typing.Optional[DetailType] = None,
+    enabled: typing.Optional[builtins.bool] = None,
+    notification_rule_name: typing.Optional[builtins.str] = None,
+    events: typing.Sequence[builtins.str],
+    source: INotificationRuleSource,
+    targets: typing.Optional[typing.Sequence[INotificationRuleTarget]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4d360e17c334b6a0f70e67ffff0c1887ea63e43f8b4efcce27df4db191f21ce0(
+    *,
+    source_arn: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a6f32c99ca69e59363f10dc680579548d678dad8805ff6c48b7a60d0aa5f940c(
+    *,
+    target_address: builtins.str,
+    target_type: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
