@@ -61,7 +61,7 @@ asset = DockerImageAsset(self, "MyBuildImage",
     build_args={
         "HTTP_PROXY": "http://10.20.30.2:1234"
     },
-    invalidation=DockerImageAssetInvalidationOptions(
+    invalidation=ecr_assets.DockerImageAssetInvalidationOptions(
         build_args=False
     )
 )
@@ -127,8 +127,8 @@ from aws_cdk.aws_ecr_assets import DockerImageAsset, Platform
 
 asset = DockerImageAsset(self, "MyBuildImage",
     directory=path.join(__dirname, "my-image"),
-    cache_from=[DockerCacheOption(type="registry", params={"ref": "ghcr.io/myorg/myimage:cache"})],
-    cache_to=DockerCacheOption(type="registry", params={"ref": "ghcr.io/myorg/myimage:cache", "mode": "max", "compression": "zstd"})
+    cache_from=[ecr_assets.DockerCacheOption(type="registry", params={"ref": "ghcr.io/myorg/myimage:cache"})],
+    cache_to=ecr_assets.DockerCacheOption(type="registry", params={"ref": "ghcr.io/myorg/myimage:cache", "mode": "max", "compression": "zstd"})
 )
 ```
 
@@ -249,8 +249,8 @@ class DockerCacheOption:
             
             asset = DockerImageAsset(self, "MyBuildImage",
                 directory=path.join(__dirname, "my-image"),
-                cache_from=[DockerCacheOption(type="registry", params={"ref": "ghcr.io/myorg/myimage:cache"})],
-                cache_to=DockerCacheOption(type="registry", params={"ref": "ghcr.io/myorg/myimage:cache", "mode": "max", "compression": "zstd"})
+                cache_from=[ecr_assets.DockerCacheOption(type="registry", params={"ref": "ghcr.io/myorg/myimage:cache"})],
+                cache_to=ecr_assets.DockerCacheOption(type="registry", params={"ref": "ghcr.io/myorg/myimage:cache", "mode": "max", "compression": "zstd"})
             )
         '''
         if __debug__:
@@ -289,8 +289,13 @@ class DockerCacheOption:
 
         Example::
 
-            # Example automatically generated from non-compiling source. May contain errors.
-            ref: `12345678.dkr.ecr.us-west-2.amazonaws.com/cache:${branch}`, mode"max"
+            # branch: str
+            
+            
+            params = {
+                "ref": f"12345678.dkr.ecr.us-west-2.amazonaws.com/cache:{branch}",
+                "mode": "max"
+            }
         '''
         result = self._values.get("params")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
@@ -328,7 +333,7 @@ class DockerImageAsset(
             build_args={
                 "HTTP_PROXY": "http://10.20.30.2:1234"
             },
-            invalidation=DockerImageAssetInvalidationOptions(
+            invalidation=ecr_assets.DockerImageAssetInvalidationOptions(
                 build_args=False
             )
         )
@@ -340,6 +345,7 @@ class DockerImageAsset(
         id: builtins.str,
         *,
         directory: builtins.str,
+        asset_name: typing.Optional[builtins.str] = None,
         build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         build_secrets: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         cache_from: typing.Optional[typing.Sequence[typing.Union[DockerCacheOption, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -359,6 +365,7 @@ class DockerImageAsset(
         :param scope: -
         :param id: -
         :param directory: The directory where the Dockerfile is stored. Any directory inside with a name that matches the CDK output folder (cdk.out by default) will be excluded from the asset
+        :param asset_name: Unique identifier of the docker image asset and its potential revisions. Required if using AppScopedStagingSynthesizer. Default: - no asset name
         :param build_args: Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
         :param build_secrets: Build secrets. Docker BuildKit must be enabled to use build secrets. Default: - no build secrets
         :param cache_from: Cache from options to pass to the ``docker build`` command. Default: - no cache from options are passed to the build command
@@ -380,6 +387,7 @@ class DockerImageAsset(
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DockerImageAssetProps(
             directory=directory,
+            asset_name=asset_name,
             build_args=build_args,
             build_secrets=build_secrets,
             cache_from=cache_from,
@@ -528,7 +536,7 @@ class DockerImageAssetInvalidationOptions:
                 build_args={
                     "HTTP_PROXY": "http://10.20.30.2:1234"
                 },
-                invalidation=DockerImageAssetInvalidationOptions(
+                invalidation=ecr_assets.DockerImageAssetInvalidationOptions(
                     build_args=False
                 )
             )
@@ -665,6 +673,7 @@ class DockerImageAssetInvalidationOptions:
         "follow_symlinks": "followSymlinks",
         "ignore_mode": "ignoreMode",
         "extra_hash": "extraHash",
+        "asset_name": "assetName",
         "build_args": "buildArgs",
         "build_secrets": "buildSecrets",
         "cache_from": "cacheFrom",
@@ -685,6 +694,7 @@ class DockerImageAssetOptions(_FileFingerprintOptions_115b8b51):
         follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
         ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
         extra_hash: typing.Optional[builtins.str] = None,
+        asset_name: typing.Optional[builtins.str] = None,
         build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         build_secrets: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         cache_from: typing.Optional[typing.Sequence[typing.Union[DockerCacheOption, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -702,6 +712,7 @@ class DockerImageAssetOptions(_FileFingerprintOptions_115b8b51):
         :param follow_symlinks: A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param ignore_mode: The ignore behavior to use for ``exclude`` patterns. Default: IgnoreMode.GLOB
         :param extra_hash: Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
+        :param asset_name: Unique identifier of the docker image asset and its potential revisions. Required if using AppScopedStagingSynthesizer. Default: - no asset name
         :param build_args: Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
         :param build_secrets: Build secrets. Docker BuildKit must be enabled to use build secrets. Default: - no build secrets
         :param cache_from: Cache from options to pass to the ``docker build`` command. Default: - no cache from options are passed to the build command
@@ -726,6 +737,7 @@ class DockerImageAssetOptions(_FileFingerprintOptions_115b8b51):
             # platform: ecr_assets.Platform
             
             docker_image_asset_options = ecr_assets.DockerImageAssetOptions(
+                asset_name="assetName",
                 build_args={
                     "build_args_key": "buildArgs"
                 },
@@ -780,6 +792,7 @@ class DockerImageAssetOptions(_FileFingerprintOptions_115b8b51):
             check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
             check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
             check_type(argname="argument extra_hash", value=extra_hash, expected_type=type_hints["extra_hash"])
+            check_type(argname="argument asset_name", value=asset_name, expected_type=type_hints["asset_name"])
             check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
             check_type(argname="argument build_secrets", value=build_secrets, expected_type=type_hints["build_secrets"])
             check_type(argname="argument cache_from", value=cache_from, expected_type=type_hints["cache_from"])
@@ -799,6 +812,8 @@ class DockerImageAssetOptions(_FileFingerprintOptions_115b8b51):
             self._values["ignore_mode"] = ignore_mode
         if extra_hash is not None:
             self._values["extra_hash"] = extra_hash
+        if asset_name is not None:
+            self._values["asset_name"] = asset_name
         if build_args is not None:
             self._values["build_args"] = build_args
         if build_secrets is not None:
@@ -859,6 +874,17 @@ class DockerImageAssetOptions(_FileFingerprintOptions_115b8b51):
         result = self._values.get("extra_hash")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def asset_name(self) -> typing.Optional[builtins.str]:
+        '''Unique identifier of the docker image asset and its potential revisions.
+
+        Required if using AppScopedStagingSynthesizer.
+
+        :default: - no asset name
+        '''
+        result = self._values.get("asset_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def build_args(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         '''Build args to pass to the ``docker build`` command.
@@ -886,8 +912,12 @@ class DockerImageAssetOptions(_FileFingerprintOptions_115b8b51):
 
         Example::
 
-            # Example automatically generated from non-compiling source. May contain errors.
-                "MY_SECRET"DockerBuildSecret.from_src("file.txt")
+            from aws_cdk import DockerBuildSecret
+            
+            
+            build_secrets = {
+                "MY_SECRET": DockerBuildSecret.from_src("file.txt")
+            }
         '''
         result = self._values.get("build_secrets")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
@@ -994,6 +1024,7 @@ class DockerImageAssetOptions(_FileFingerprintOptions_115b8b51):
         "follow_symlinks": "followSymlinks",
         "ignore_mode": "ignoreMode",
         "extra_hash": "extraHash",
+        "asset_name": "assetName",
         "build_args": "buildArgs",
         "build_secrets": "buildSecrets",
         "cache_from": "cacheFrom",
@@ -1015,6 +1046,7 @@ class DockerImageAssetProps(DockerImageAssetOptions):
         follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
         ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
         extra_hash: typing.Optional[builtins.str] = None,
+        asset_name: typing.Optional[builtins.str] = None,
         build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         build_secrets: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         cache_from: typing.Optional[typing.Sequence[typing.Union[DockerCacheOption, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -1033,6 +1065,7 @@ class DockerImageAssetProps(DockerImageAssetOptions):
         :param follow_symlinks: A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param ignore_mode: The ignore behavior to use for ``exclude`` patterns. Default: IgnoreMode.GLOB
         :param extra_hash: Extra information to encode into the fingerprint (e.g. build instructions and other inputs). Default: - hash is only based on source content
+        :param asset_name: Unique identifier of the docker image asset and its potential revisions. Required if using AppScopedStagingSynthesizer. Default: - no asset name
         :param build_args: Build args to pass to the ``docker build`` command. Since Docker build arguments are resolved before deployment, keys and values cannot refer to unresolved tokens (such as ``lambda.functionArn`` or ``queue.queueUrl``). Default: - no build args are passed
         :param build_secrets: Build secrets. Docker BuildKit must be enabled to use build secrets. Default: - no build secrets
         :param cache_from: Cache from options to pass to the ``docker build`` command. Default: - no cache from options are passed to the build command
@@ -1057,7 +1090,7 @@ class DockerImageAssetProps(DockerImageAssetOptions):
                 build_args={
                     "HTTP_PROXY": "http://10.20.30.2:1234"
                 },
-                invalidation=DockerImageAssetInvalidationOptions(
+                invalidation=ecr_assets.DockerImageAssetInvalidationOptions(
                     build_args=False
                 )
             )
@@ -1072,6 +1105,7 @@ class DockerImageAssetProps(DockerImageAssetOptions):
             check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
             check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
             check_type(argname="argument extra_hash", value=extra_hash, expected_type=type_hints["extra_hash"])
+            check_type(argname="argument asset_name", value=asset_name, expected_type=type_hints["asset_name"])
             check_type(argname="argument build_args", value=build_args, expected_type=type_hints["build_args"])
             check_type(argname="argument build_secrets", value=build_secrets, expected_type=type_hints["build_secrets"])
             check_type(argname="argument cache_from", value=cache_from, expected_type=type_hints["cache_from"])
@@ -1094,6 +1128,8 @@ class DockerImageAssetProps(DockerImageAssetOptions):
             self._values["ignore_mode"] = ignore_mode
         if extra_hash is not None:
             self._values["extra_hash"] = extra_hash
+        if asset_name is not None:
+            self._values["asset_name"] = asset_name
         if build_args is not None:
             self._values["build_args"] = build_args
         if build_secrets is not None:
@@ -1154,6 +1190,17 @@ class DockerImageAssetProps(DockerImageAssetOptions):
         result = self._values.get("extra_hash")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def asset_name(self) -> typing.Optional[builtins.str]:
+        '''Unique identifier of the docker image asset and its potential revisions.
+
+        Required if using AppScopedStagingSynthesizer.
+
+        :default: - no asset name
+        '''
+        result = self._values.get("asset_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def build_args(self) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
         '''Build args to pass to the ``docker build`` command.
@@ -1181,8 +1228,12 @@ class DockerImageAssetProps(DockerImageAssetOptions):
 
         Example::
 
-            # Example automatically generated from non-compiling source. May contain errors.
-                "MY_SECRET"DockerBuildSecret.from_src("file.txt")
+            from aws_cdk import DockerBuildSecret
+            
+            
+            build_secrets = {
+                "MY_SECRET": DockerBuildSecret.from_src("file.txt")
+            }
         '''
         result = self._values.get("build_secrets")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
@@ -1581,6 +1632,7 @@ def _typecheckingstub__797fbc31925afd247c6567a5b5c30dcdc13a3d9b17aba80ece42c86bd
     id: builtins.str,
     *,
     directory: builtins.str,
+    asset_name: typing.Optional[builtins.str] = None,
     build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     build_secrets: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     cache_from: typing.Optional[typing.Sequence[typing.Union[DockerCacheOption, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -1639,6 +1691,7 @@ def _typecheckingstub__be58b9ab6157641d31b553709d8decad6c9801460bec8e3ff07aadc33
     follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
     ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
     extra_hash: typing.Optional[builtins.str] = None,
+    asset_name: typing.Optional[builtins.str] = None,
     build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     build_secrets: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     cache_from: typing.Optional[typing.Sequence[typing.Union[DockerCacheOption, typing.Dict[builtins.str, typing.Any]]]] = None,
@@ -1659,6 +1712,7 @@ def _typecheckingstub__1abde6bc94231492c7b40171b32143e7c5533e907120fe3e3c2ebeca2
     follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
     ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
     extra_hash: typing.Optional[builtins.str] = None,
+    asset_name: typing.Optional[builtins.str] = None,
     build_args: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     build_secrets: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
     cache_from: typing.Optional[typing.Sequence[typing.Union[DockerCacheOption, typing.Dict[builtins.str, typing.Any]]]] = None,
