@@ -274,6 +274,7 @@ class Asset(
         id: builtins.str,
         *,
         path: builtins.str,
+        deploy_time: typing.Optional[builtins.bool] = None,
         readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
         asset_hash: typing.Optional[builtins.str] = None,
         asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
@@ -286,6 +287,7 @@ class Asset(
         :param scope: -
         :param id: -
         :param path: The disk location of the asset. The path should refer to one of the following: - A regular file or a .zip file, in which case the file will be uploaded as-is to S3. - A directory, in which case it will be archived into a .zip file and uploaded to S3.
+        :param deploy_time: Whether or not the asset needs to exist beyond deployment time; i.e. are copied over to a different location and not needed afterwards. Setting this property to true has an impact on the lifecycle of the asset, because we will assume that it is safe to delete after the CloudFormation deployment succeeds. For example, Lambda Function assets are copied over to Lambda during deployment. Therefore, it is not necessary to store the asset in S3, so we consider those deployTime assets. Default: false
         :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
         :param asset_hash: Specify a custom hash for this asset. If ``assetHashType`` is set it must be set to ``AssetHashType.CUSTOM``. For consistency, this custom hash will be SHA256 hashed and encoded as hex. The resulting hash will be the asset hash. NOTE: the hash is used in order to identify a specific revision of the asset, and used for optimizing and caching deployment activities related to this asset such as packaging, uploading to Amazon S3, etc. If you chose to customize the hash, you will need to make sure it is updated every time the asset changes, or otherwise it is possible that some deployments will not be invalidated. Default: - based on ``assetHashType``
         :param asset_hash_type: Specifies the type of hash to calculate for this asset. If ``assetHash`` is configured, this option must be ``undefined`` or ``AssetHashType.CUSTOM``. Default: - the default is ``AssetHashType.SOURCE``, but if ``assetHash`` is explicitly specified this value defaults to ``AssetHashType.CUSTOM``.
@@ -300,6 +302,7 @@ class Asset(
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AssetProps(
             path=path,
+            deploy_time=deploy_time,
             readers=readers,
             asset_hash=asset_hash,
             asset_hash_type=asset_hash_type,
@@ -436,6 +439,7 @@ class Asset(
         "exclude": "exclude",
         "follow_symlinks": "followSymlinks",
         "ignore_mode": "ignoreMode",
+        "deploy_time": "deployTime",
         "readers": "readers",
     },
 )
@@ -449,6 +453,7 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
         ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
+        deploy_time: typing.Optional[builtins.bool] = None,
         readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
     ) -> None:
         '''
@@ -458,6 +463,7 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
         :param exclude: File paths matching the patterns will be excluded. See ``ignoreMode`` to set the matching behavior. Has no effect on Assets bundled using the ``bundling`` property. Default: - nothing is excluded
         :param follow_symlinks: A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param ignore_mode: The ignore behavior to use for ``exclude`` patterns. Default: IgnoreMode.GLOB
+        :param deploy_time: Whether or not the asset needs to exist beyond deployment time; i.e. are copied over to a different location and not needed afterwards. Setting this property to true has an impact on the lifecycle of the asset, because we will assume that it is safe to delete after the CloudFormation deployment succeeds. For example, Lambda Function assets are copied over to Lambda during deployment. Therefore, it is not necessary to store the asset in S3, so we consider those deployTime assets. Default: false
         :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
 
         :exampleMetadata: infused
@@ -486,6 +492,7 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
             check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
             check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
             check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+            check_type(argname="argument deploy_time", value=deploy_time, expected_type=type_hints["deploy_time"])
             check_type(argname="argument readers", value=readers, expected_type=type_hints["readers"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if asset_hash is not None:
@@ -500,6 +507,8 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
             self._values["follow_symlinks"] = follow_symlinks
         if ignore_mode is not None:
             self._values["ignore_mode"] = ignore_mode
+        if deploy_time is not None:
+            self._values["deploy_time"] = deploy_time
         if readers is not None:
             self._values["readers"] = readers
 
@@ -585,6 +594,25 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
         result = self._values.get("ignore_mode")
         return typing.cast(typing.Optional[_IgnoreMode_655a98e8], result)
 
+    @builtins.property
+    def deploy_time(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not the asset needs to exist beyond deployment time;
+
+        i.e.
+        are copied over to a different location and not needed afterwards.
+        Setting this property to true has an impact on the lifecycle of the asset,
+        because we will assume that it is safe to delete after the CloudFormation
+        deployment succeeds.
+
+        For example, Lambda Function assets are copied over to Lambda during
+        deployment. Therefore, it is not necessary to store the asset in S3, so
+        we consider those deployTime assets.
+
+        :default: false
+        '''
+        result = self._values.get("deploy_time")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def readers(self) -> typing.Optional[typing.List[_IGrantable_71c4f5de]]:
         '''A list of principals that should be able to read this asset from S3.
@@ -618,6 +646,7 @@ class AssetOptions(_AssetOptions_9cd3031e, _FileCopyOptions_e03e2a30):
         "exclude": "exclude",
         "follow_symlinks": "followSymlinks",
         "ignore_mode": "ignoreMode",
+        "deploy_time": "deployTime",
         "readers": "readers",
         "path": "path",
     },
@@ -632,6 +661,7 @@ class AssetProps(AssetOptions):
         exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
         follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
         ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
+        deploy_time: typing.Optional[builtins.bool] = None,
         readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
         path: builtins.str,
     ) -> None:
@@ -642,6 +672,7 @@ class AssetProps(AssetOptions):
         :param exclude: File paths matching the patterns will be excluded. See ``ignoreMode`` to set the matching behavior. Has no effect on Assets bundled using the ``bundling`` property. Default: - nothing is excluded
         :param follow_symlinks: A strategy for how to handle symlinks. Default: SymlinkFollowMode.NEVER
         :param ignore_mode: The ignore behavior to use for ``exclude`` patterns. Default: IgnoreMode.GLOB
+        :param deploy_time: Whether or not the asset needs to exist beyond deployment time; i.e. are copied over to a different location and not needed afterwards. Setting this property to true has an impact on the lifecycle of the asset, because we will assume that it is safe to delete after the CloudFormation deployment succeeds. For example, Lambda Function assets are copied over to Lambda during deployment. Therefore, it is not necessary to store the asset in S3, so we consider those deployTime assets. Default: false
         :param readers: A list of principals that should be able to read this asset from S3. You can use ``asset.grantRead(principal)`` to grant read permissions later. Default: - No principals that can read file asset.
         :param path: The disk location of the asset. The path should refer to one of the following: - A regular file or a .zip file, in which case the file will be uploaded as-is to S3. - A directory, in which case it will be archived into a .zip file and uploaded to S3.
 
@@ -671,6 +702,7 @@ class AssetProps(AssetOptions):
             check_type(argname="argument exclude", value=exclude, expected_type=type_hints["exclude"])
             check_type(argname="argument follow_symlinks", value=follow_symlinks, expected_type=type_hints["follow_symlinks"])
             check_type(argname="argument ignore_mode", value=ignore_mode, expected_type=type_hints["ignore_mode"])
+            check_type(argname="argument deploy_time", value=deploy_time, expected_type=type_hints["deploy_time"])
             check_type(argname="argument readers", value=readers, expected_type=type_hints["readers"])
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
@@ -688,6 +720,8 @@ class AssetProps(AssetOptions):
             self._values["follow_symlinks"] = follow_symlinks
         if ignore_mode is not None:
             self._values["ignore_mode"] = ignore_mode
+        if deploy_time is not None:
+            self._values["deploy_time"] = deploy_time
         if readers is not None:
             self._values["readers"] = readers
 
@@ -773,6 +807,25 @@ class AssetProps(AssetOptions):
         result = self._values.get("ignore_mode")
         return typing.cast(typing.Optional[_IgnoreMode_655a98e8], result)
 
+    @builtins.property
+    def deploy_time(self) -> typing.Optional[builtins.bool]:
+        '''Whether or not the asset needs to exist beyond deployment time;
+
+        i.e.
+        are copied over to a different location and not needed afterwards.
+        Setting this property to true has an impact on the lifecycle of the asset,
+        because we will assume that it is safe to delete after the CloudFormation
+        deployment succeeds.
+
+        For example, Lambda Function assets are copied over to Lambda during
+        deployment. Therefore, it is not necessary to store the asset in S3, so
+        we consider those deployTime assets.
+
+        :default: false
+        '''
+        result = self._values.get("deploy_time")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def readers(self) -> typing.Optional[typing.List[_IGrantable_71c4f5de]]:
         '''A list of principals that should be able to read this asset from S3.
@@ -822,6 +875,7 @@ def _typecheckingstub__00df81fd3b746cf2ee52c0e7a23b6fdc1b45db97673ca7e25a9651e7e
     id: builtins.str,
     *,
     path: builtins.str,
+    deploy_time: typing.Optional[builtins.bool] = None,
     readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
     asset_hash: typing.Optional[builtins.str] = None,
     asset_hash_type: typing.Optional[_AssetHashType_05b67f2d] = None,
@@ -854,6 +908,7 @@ def _typecheckingstub__11950fe0327642dd25ddfeb2c620bb33847718475fe489bf003d096a0
     exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
     follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
     ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
+    deploy_time: typing.Optional[builtins.bool] = None,
     readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
 ) -> None:
     """Type checking stubs"""
@@ -867,6 +922,7 @@ def _typecheckingstub__f879318d3885bc2e9c71c124fac7ad5a955812e438be7c03244c3aad7
     exclude: typing.Optional[typing.Sequence[builtins.str]] = None,
     follow_symlinks: typing.Optional[_SymlinkFollowMode_047ec1f6] = None,
     ignore_mode: typing.Optional[_IgnoreMode_655a98e8] = None,
+    deploy_time: typing.Optional[builtins.bool] = None,
     readers: typing.Optional[typing.Sequence[_IGrantable_71c4f5de]] = None,
     path: builtins.str,
 ) -> None:
