@@ -387,7 +387,7 @@ class CfnSigningProfile(
 ):
     '''A CloudFormation ``AWS::Signer::SigningProfile``.
 
-    Creates a signing profile. A signing profile is a code signing template that can be used to carry out a pre-defined signing job.
+    Creates a signing profile. A signing profile is a code-signing template that can be used to carry out a pre-defined signing job.
 
     :cloudformationResource: AWS::Signer::SigningProfile
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-signer-signingprofile.html
@@ -476,7 +476,8 @@ class CfnSigningProfile(
     @builtins.property
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
-        '''
+        '''The Amazon Resource Name (ARN) of the signing profile created.
+
         :cloudformationAttribute: Arn
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrArn"))
@@ -484,7 +485,8 @@ class CfnSigningProfile(
     @builtins.property
     @jsii.member(jsii_name="attrProfileName")
     def attr_profile_name(self) -> builtins.str:
-        '''
+        '''The name of the signing profile created.
+
         :cloudformationAttribute: ProfileName
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrProfileName"))
@@ -492,7 +494,8 @@ class CfnSigningProfile(
     @builtins.property
     @jsii.member(jsii_name="attrProfileVersion")
     def attr_profile_version(self) -> builtins.str:
-        '''
+        '''The version of the signing profile created.
+
         :cloudformationAttribute: ProfileVersion
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrProfileVersion"))
@@ -500,7 +503,8 @@ class CfnSigningProfile(
     @builtins.property
     @jsii.member(jsii_name="attrProfileVersionArn")
     def attr_profile_version_arn(self) -> builtins.str:
-        '''
+        '''The signing profile ARN, including the profile version.
+
         :cloudformationAttribute: ProfileVersionArn
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrProfileVersionArn"))
