@@ -125,7 +125,8 @@ make sure to download the unprocessed template
 However, certain unprocessed templates can fail when used with the `CfnInclude` class.
 The most common reason for the failure is that the unprocessed template can contain cycles between resources,
 which get removed after the Transform is processed,
-but is not allowed when being included (as pure CloudFormation does not permit cycles).
+but is not allowed when being included (as pure CloudFormation does not permit cycles). To enable cycle processing behavior similar
+to cloudformation, set `allowCyclicalReferences` of CfnIncludeProps to true.
 
 When that happens, you should instead download the processed template from the CloudFormation AWS Console
 (make sure the "View processed template" checkbox is **checked** in that case):
@@ -480,7 +481,7 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import constructs
+import constructs as _constructs_77d1e7e8
 from .. import (
     CfnCondition as _CfnCondition_ac3c7d25,
     CfnElement as _CfnElement_8a9d213c,
@@ -501,7 +502,7 @@ class CfnInclude(
 ):
     '''Construct to import an existing CloudFormation template file into a CDK application.
 
-    All resources defined in the template file can be retrieved by calling the {@link getResource} method.
+    All resources defined in the template file can be retrieved by calling the ``getResource`` method.
     Any modifications made on the returned resource objects will be reflected in the resulting CDK template.
 
     :exampleMetadata: infused
@@ -515,11 +516,12 @@ class CfnInclude(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
+        allow_cyclical_references: typing.Optional[builtins.bool] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[builtins.str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
@@ -527,16 +529,18 @@ class CfnInclude(
         :param scope: -
         :param id: -
         :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param allow_cyclical_references: Specifies whether to allow cyclical references, effectively disregarding safeguards meant to avoid undeployable templates. This should only be set to true in the case of templates utilizing cloud transforms (e.g. SAM) that after processing the transform will no longer contain any circular references. Default: - will throw an error on detecting any cyclical references
+        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the ``CfnInclude.getNestedStack`` method (but will still be accessible from the ``CfnInclude.getResource`` method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
         :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. If you are importing a parameter from a live stack, we cannot know the value of that parameter. You will need to supply a value for your parameters, else the default value will be used. Default: - parameters will retain their original definitions
-        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
+        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the ``CfnInclude.getResource`` and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4185853ea24f6986c8394bfadb21bcc9f34dfbaabb091ba9acbe1da7d8f7c737)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnIncludeProps(
             template_file=template_file,
+            allow_cyclical_references=allow_cyclical_references,
             load_nested_stacks=load_nested_stacks,
             parameters=parameters,
             preserve_logical_ids=preserve_logical_ids,
@@ -556,7 +560,7 @@ class CfnInclude(
         :param condition_name: the name of the Condition in the CloudFormation template file.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_condition)
+            type_hints = typing.get_type_hints(_typecheckingstub__dfdc3baf6bf8e46f580841d902753af49289b342fdcbc7053c9314d63aa7eb72)
             check_type(argname="argument condition_name", value=condition_name, expected_type=type_hints["condition_name"])
         return typing.cast(_CfnCondition_ac3c7d25, jsii.invoke(self, "getCondition", [condition_name]))
 
@@ -572,7 +576,7 @@ class CfnInclude(
         :param hook_logical_id: the logical ID of the Hook in the included CloudFormation template's 'Hooks' section.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_hook)
+            type_hints = typing.get_type_hints(_typecheckingstub__25c5b6f4b9e985a3ca491693f4edbc7c23e5ef3a820220ed3b121e47cec61047)
             check_type(argname="argument hook_logical_id", value=hook_logical_id, expected_type=type_hints["hook_logical_id"])
         return typing.cast(_CfnHook_1d3dbe57, jsii.invoke(self, "getHook", [hook_logical_id]))
 
@@ -588,7 +592,7 @@ class CfnInclude(
         :param mapping_name: the name of the Mapping in the template to retrieve.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_mapping)
+            type_hints = typing.get_type_hints(_typecheckingstub__fef39fd8f5ff4e76d8270fd817c9d8eb4a8d89399e7cd4ad3c1b426ecf5860e2)
             check_type(argname="argument mapping_name", value=mapping_name, expected_type=type_hints["mapping_name"])
         return typing.cast(_CfnMapping_00f8fc17, jsii.invoke(self, "getMapping", [mapping_name]))
 
@@ -597,13 +601,13 @@ class CfnInclude(
         '''Returns a loaded NestedStack with name logicalId.
 
         For a nested stack to be returned by this method,
-        it must be specified either in the {@link CfnIncludeProps.loadNestedStacks} property,
-        or through the {@link loadNestedStack} method.
+        it must be specified either in the ``CfnIncludeProps.loadNestedStacks`` property,
+        or through the ``loadNestedStack`` method.
 
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_nested_stack)
+            type_hints = typing.get_type_hints(_typecheckingstub__37a735b43816229ef0c9c743f6455422b50938ecaae7a978e10925cdf4f54885)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast("IncludedNestedStack", jsii.invoke(self, "getNestedStack", [logical_id]))
 
@@ -619,7 +623,7 @@ class CfnInclude(
         :param logical_id: the name of the output to retrieve.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_output)
+            type_hints = typing.get_type_hints(_typecheckingstub__51feb7c844e6986c4703dc16d92978a639f0bef0e6fc677fd84625bedd25f1e0)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast(_CfnOutput_7273f911, jsii.invoke(self, "getOutput", [logical_id]))
 
@@ -635,7 +639,7 @@ class CfnInclude(
         :param parameter_name: the name of the parameter to retrieve.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_parameter)
+            type_hints = typing.get_type_hints(_typecheckingstub__8c7269102b214cdeb3fcc3da004ae2f41866723648ea084e5eebea16e3c93ce2)
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
         return typing.cast(_CfnParameter_48fc1866, jsii.invoke(self, "getParameter", [parameter_name]))
 
@@ -648,9 +652,9 @@ class CfnInclude(
         The returned object will be of the proper underlying class;
         you can always cast it to the correct type in your code::
 
-            // assume the template contains an AWS::S3::Bucket with logical ID 'Bucket'
-            const cfnBucket = cfnTemplate.getResource('Bucket') as s3.CfnBucket;
-            // cfnBucket is of type s3.CfnBucket
+           // assume the template contains an AWS::S3::Bucket with logical ID 'Bucket'
+           const cfnBucket = cfnTemplate.getResource('Bucket') as s3.CfnBucket;
+           // cfnBucket is of type s3.CfnBucket
 
         If the template does not contain a resource with the given logical ID,
         an exception will be thrown.
@@ -658,7 +662,7 @@ class CfnInclude(
         :param logical_id: the logical ID of the resource in the CloudFormation template file.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_resource)
+            type_hints = typing.get_type_hints(_typecheckingstub__fd3c5e46dcacf54cf69606d9e214b10ea546d33f5aec335f84c2e709e780df91)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast(_CfnResource_9df397a6, jsii.invoke(self, "getResource", [logical_id]))
 
@@ -674,7 +678,7 @@ class CfnInclude(
         :param rule_name: the name of the Rule in the CloudFormation template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_rule)
+            type_hints = typing.get_type_hints(_typecheckingstub__20ba00e1d33346f6b5c5629a14e683c03700d80b4ef6dd86c6bb6077fe00c79e)
             check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
         return typing.cast(_CfnRule_1d9ee4c6, jsii.invoke(self, "getRule", [rule_name]))
 
@@ -684,7 +688,8 @@ class CfnInclude(
         logical_id: builtins.str,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
+        allow_cyclical_references: typing.Optional[builtins.bool] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[builtins.str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> "IncludedNestedStack":
@@ -692,22 +697,24 @@ class CfnInclude(
 
         A child with this logical ID must exist in the template,
         and be of type AWS::CloudFormation::Stack.
-        This is equivalent to specifying the value in the {@link CfnIncludeProps.loadNestedStacks}
+        This is equivalent to specifying the value in the ``CfnIncludeProps.loadNestedStacks``
         property on object construction.
 
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
         :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param allow_cyclical_references: Specifies whether to allow cyclical references, effectively disregarding safeguards meant to avoid undeployable templates. This should only be set to true in the case of templates utilizing cloud transforms (e.g. SAM) that after processing the transform will no longer contain any circular references. Default: - will throw an error on detecting any cyclical references
+        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the ``CfnInclude.getNestedStack`` method (but will still be accessible from the ``CfnInclude.getResource`` method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
         :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. If you are importing a parameter from a live stack, we cannot know the value of that parameter. You will need to supply a value for your parameters, else the default value will be used. Default: - parameters will retain their original definitions
-        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
+        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the ``CfnInclude.getResource`` and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
 
-        :return: the same {@link IncludedNestedStack} object that {@link getNestedStack} returns for this logical ID
+        :return: the same ``IncludedNestedStack`` object that ``getNestedStack`` returns for this logical ID
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.load_nested_stack)
+            type_hints = typing.get_type_hints(_typecheckingstub__1de5dca9b9d136124e6e84c51950c6936c1c380a5f8a618f7f849bd32e499be6)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         nested_stack_props = CfnIncludeProps(
             template_file=template_file,
+            allow_cyclical_references=allow_cyclical_references,
             load_nested_stacks=load_nested_stacks,
             parameters=parameters,
             preserve_logical_ids=preserve_logical_ids,
@@ -721,6 +728,7 @@ class CfnInclude(
     jsii_struct_bases=[],
     name_mapping={
         "template_file": "templateFile",
+        "allow_cyclical_references": "allowCyclicalReferences",
         "load_nested_stacks": "loadNestedStacks",
         "parameters": "parameters",
         "preserve_logical_ids": "preserveLogicalIds",
@@ -731,16 +739,18 @@ class CfnIncludeProps:
         self,
         *,
         template_file: builtins.str,
-        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[str, typing.Any]]]] = None,
+        allow_cyclical_references: typing.Optional[builtins.bool] = None,
+        load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union["CfnIncludeProps", typing.Dict[builtins.str, typing.Any]]]] = None,
         parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
         preserve_logical_ids: typing.Optional[builtins.bool] = None,
     ) -> None:
-        '''Construction properties of {@link CfnInclude}.
+        '''Construction properties of ``CfnInclude``.
 
         :param template_file: Path to the template file. Both JSON and YAML template formats are supported.
-        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method (but will still be accessible from the {@link CfnInclude.getResource} method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
+        :param allow_cyclical_references: Specifies whether to allow cyclical references, effectively disregarding safeguards meant to avoid undeployable templates. This should only be set to true in the case of templates utilizing cloud transforms (e.g. SAM) that after processing the transform will no longer contain any circular references. Default: - will throw an error on detecting any cyclical references
+        :param load_nested_stacks: Specifies the template files that define nested stacks that should be included. If your template specifies a stack that isn't included here, it won't be created as a NestedStack resource, and it won't be accessible from the ``CfnInclude.getNestedStack`` method (but will still be accessible from the ``CfnInclude.getResource`` method). If you include a stack here with an ID that isn't in the template, or is in the template but is not a nested stack, template creation will fail and an error will be thrown. Default: - no nested stacks will be included
         :param parameters: Specifies parameters to be replaced by the values in this mapping. Any parameters in the template that aren't specified here will be left unmodified. If you include a parameter here with an ID that isn't in the template, template creation will fail and an error will be thrown. If you are importing a parameter from a live stack, we cannot know the value of that parameter. You will need to supply a value for your parameters, else the default value will be used. Default: - parameters will retain their original definitions
-        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
+        :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the ``CfnInclude.getResource`` and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
 
         :exampleMetadata: infused
 
@@ -756,14 +766,17 @@ class CfnIncludeProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnIncludeProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ec894574320f1d1806f81c6bd6f030b31c90de46348de376f43cb70a72909217)
             check_type(argname="argument template_file", value=template_file, expected_type=type_hints["template_file"])
+            check_type(argname="argument allow_cyclical_references", value=allow_cyclical_references, expected_type=type_hints["allow_cyclical_references"])
             check_type(argname="argument load_nested_stacks", value=load_nested_stacks, expected_type=type_hints["load_nested_stacks"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
             check_type(argname="argument preserve_logical_ids", value=preserve_logical_ids, expected_type=type_hints["preserve_logical_ids"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "template_file": template_file,
         }
+        if allow_cyclical_references is not None:
+            self._values["allow_cyclical_references"] = allow_cyclical_references
         if load_nested_stacks is not None:
             self._values["load_nested_stacks"] = load_nested_stacks
         if parameters is not None:
@@ -781,6 +794,18 @@ class CfnIncludeProps:
         assert result is not None, "Required property 'template_file' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def allow_cyclical_references(self) -> typing.Optional[builtins.bool]:
+        '''Specifies whether to allow cyclical references, effectively disregarding safeguards meant to avoid undeployable templates.
+
+        This should only be set to true in the case of templates utilizing cloud transforms (e.g. SAM) that
+        after processing the transform will no longer contain any circular references.
+
+        :default: - will throw an error on detecting any cyclical references
+        '''
+        result = self._values.get("allow_cyclical_references")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def load_nested_stacks(
         self,
@@ -788,8 +813,8 @@ class CfnIncludeProps:
         '''Specifies the template files that define nested stacks that should be included.
 
         If your template specifies a stack that isn't included here, it won't be created as a NestedStack
-        resource, and it won't be accessible from the {@link CfnInclude.getNestedStack} method
-        (but will still be accessible from the {@link CfnInclude.getResource} method).
+        resource, and it won't be accessible from the ``CfnInclude.getNestedStack`` method
+        (but will still be accessible from the ``CfnInclude.getResource`` method).
 
         If you include a stack here with an ID that isn't in the template,
         or is in the template but is not a nested stack,
@@ -825,7 +850,7 @@ class CfnIncludeProps:
         make sure to pass this as ``false``.
 
         **Note**: regardless of whether this option is true or false,
-        the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element,
+        the ``CfnInclude.getResource`` and related methods always uses the original logical ID of the resource/element,
         as specified in the template file.
 
         :default: true
@@ -857,7 +882,7 @@ class IncludedNestedStack:
         included_template: CfnInclude,
         stack: _NestedStack_dd393a45,
     ) -> None:
-        '''The type returned from {@link CfnInclude.getNestedStack}. Contains both the NestedStack object and CfnInclude representations of the child stack.
+        '''The type returned from ``CfnInclude.getNestedStack``. Contains both the NestedStack object and CfnInclude representations of the child stack.
 
         :param included_template: The CfnInclude that represents the template, which can be used to access Resources and other template elements.
         :param stack: The NestedStack object which represents the scope of the template.
@@ -874,10 +899,10 @@ class IncludedNestedStack:
             child_template = included_child_stack.included_template
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IncludedNestedStack.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__88e7af25c222ba7dccf8297352c3a575d3d8de37e00247a88dab0bd7f7099fe3)
             check_type(argname="argument included_template", value=included_template, expected_type=type_hints["included_template"])
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "included_template": included_template,
             "stack": stack,
         }
@@ -915,3 +940,95 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__4185853ea24f6986c8394bfadb21bcc9f34dfbaabb091ba9acbe1da7d8f7c737(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    template_file: builtins.str,
+    allow_cyclical_references: typing.Optional[builtins.bool] = None,
+    load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[builtins.str, typing.Any]]]] = None,
+    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+    preserve_logical_ids: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dfdc3baf6bf8e46f580841d902753af49289b342fdcbc7053c9314d63aa7eb72(
+    condition_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__25c5b6f4b9e985a3ca491693f4edbc7c23e5ef3a820220ed3b121e47cec61047(
+    hook_logical_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fef39fd8f5ff4e76d8270fd817c9d8eb4a8d89399e7cd4ad3c1b426ecf5860e2(
+    mapping_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__37a735b43816229ef0c9c743f6455422b50938ecaae7a978e10925cdf4f54885(
+    logical_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__51feb7c844e6986c4703dc16d92978a639f0bef0e6fc677fd84625bedd25f1e0(
+    logical_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8c7269102b214cdeb3fcc3da004ae2f41866723648ea084e5eebea16e3c93ce2(
+    parameter_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__fd3c5e46dcacf54cf69606d9e214b10ea546d33f5aec335f84c2e709e780df91(
+    logical_id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__20ba00e1d33346f6b5c5629a14e683c03700d80b4ef6dd86c6bb6077fe00c79e(
+    rule_name: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1de5dca9b9d136124e6e84c51950c6936c1c380a5f8a618f7f849bd32e499be6(
+    logical_id: builtins.str,
+    *,
+    template_file: builtins.str,
+    allow_cyclical_references: typing.Optional[builtins.bool] = None,
+    load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[builtins.str, typing.Any]]]] = None,
+    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+    preserve_logical_ids: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ec894574320f1d1806f81c6bd6f030b31c90de46348de376f43cb70a72909217(
+    *,
+    template_file: builtins.str,
+    allow_cyclical_references: typing.Optional[builtins.bool] = None,
+    load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[builtins.str, typing.Any]]]] = None,
+    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+    preserve_logical_ids: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__88e7af25c222ba7dccf8297352c3a575d3d8de37e00247a88dab0bd7f7099fe3(
+    *,
+    included_template: CfnInclude,
+    stack: _NestedStack_dd393a45,
+) -> None:
+    """Type checking stubs"""
+    pass
