@@ -136,7 +136,7 @@ class Fact(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.region_info.Fact"):
         @jsii.implements(region_info.IFact)
         class MyFact:
         
-        region_info.Fact.register(MyFact())
+        region_info.Fact.register(MyFact(), True)
     '''
 
     @jsii.member(jsii_name="find")
@@ -237,7 +237,7 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.region_info.FactN
         @jsii.implements(region_info.IFact)
         class MyFact:
         
-        region_info.Fact.register(MyFact())
+        region_info.Fact.register(MyFact(), True)
     '''
 
     def __init__(self) -> None:
@@ -282,6 +282,24 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.region_info.FactN
             check_type(argname="argument arch", value=arch, expected_type=type_hints["arch"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "cloudwatchLambdaInsightsVersion", [version, arch]))
 
+    @jsii.member(jsii_name="paramsAndSecretsLambdaLayer")
+    @builtins.classmethod
+    def params_and_secrets_lambda_layer(
+        cls,
+        version: builtins.str,
+        architecture: builtins.str,
+    ) -> builtins.str:
+        '''The ARN of Parameters and Secrets Lambda layer for a given lambda architecture.
+
+        :param version: the layer version.
+        :param architecture: the Lambda Function architecture (e.g. 'x86_64' or 'arm64').
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__31e85af17141cb06d78caf690b404140a60da484702dae653fb870c38266e1cb)
+            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
+            check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
+        return typing.cast(builtins.str, jsii.sinvoke(cls, "paramsAndSecretsLambdaLayer", [version, architecture]))
+
     @jsii.member(jsii_name="servicePrincipal")
     @builtins.classmethod
     def service_principal(cls, service: builtins.str) -> builtins.str:
@@ -310,6 +328,12 @@ class FactName(metaclass=jsii.JSIIMeta, jsii_type="aws-cdk-lib.region_info.FactN
         '''
         return typing.cast(builtins.str, jsii.sget(cls, "CDK_METADATA_RESOURCE_AVAILABLE"))
 
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="DEFAULT_CR_NODE_VERSION")
+    def DEFAULT_CR_NODE_VERSION(cls) -> builtins.str:
+        '''The default NodeJS version used for custom resource function runtimes.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "DEFAULT_CR_NODE_VERSION"))
+
     @jsii.python.classproperty
     @jsii.member(jsii_name="DLC_REPOSITORY_ACCOUNT")
     def DLC_REPOSITORY_ACCOUNT(cls) -> builtins.str:
@@ -541,6 +565,23 @@ class RegionInfo(
             check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
         return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "cloudwatchLambdaInsightsArn", [insights_version, architecture]))
 
+    @jsii.member(jsii_name="paramsAndSecretsLambdaLayerArn")
+    def params_and_secrets_lambda_layer_arn(
+        self,
+        version: builtins.str,
+        architecture: builtins.str,
+    ) -> typing.Optional[builtins.str]:
+        '''The ARN of the Parameters and Secrets Lambda layer for the given lambda architecture.
+
+        :param version: the layer version.
+        :param architecture: the Lambda Function architecture (e.g. 'x86_64' or 'arm64').
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__6b956146d487195c3acb1779c0146a94aee85876962f555b1e971c8ce90ec930)
+            check_type(argname="argument version", value=version, expected_type=type_hints["version"])
+            check_type(argname="argument architecture", value=architecture, expected_type=type_hints["architecture"])
+        return typing.cast(typing.Optional[builtins.str], jsii.invoke(self, "paramsAndSecretsLambdaLayerArn", [version, architecture]))
+
     @jsii.member(jsii_name="servicePrincipal")
     def service_principal(self, service: builtins.str) -> typing.Optional[builtins.str]:
         '''The name of the service principal for a given service in this region.
@@ -703,6 +744,13 @@ def _typecheckingstub__43e6018c25205623b05e3dea383d535db52915f6e910faa0b43bd987f
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__31e85af17141cb06d78caf690b404140a60da484702dae653fb870c38266e1cb(
+    version: builtins.str,
+    architecture: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__b14fde076501b6bbe3459fe473f8a85eda6046b48c735804859dd2c381a5566f(
     service: builtins.str,
 ) -> None:
@@ -743,6 +791,13 @@ def _typecheckingstub__cce016d7f88a7bd5b91741d5a6afd2c644bef86b54f2533ad6dc772d8
     """Type checking stubs"""
     pass
 
+def _typecheckingstub__6b956146d487195c3acb1779c0146a94aee85876962f555b1e971c8ce90ec930(
+    version: builtins.str,
+    architecture: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
 def _typecheckingstub__b7fa00c6eee8344d2d7dec9a9b3e5aabd291377b56af4261818a521770e400cf(
     service: builtins.str,
 ) -> None:
